# Change Log

## [0.0.2] -  2023-11-13

### Fixed
- tracking board locations failing when item added a status with nothing in it yet [djay]
- fix hardcoded org [conbrad]
- fix bug if no exclude pipeline [conbrad]

## [0.0.1] - 2023-07-22

### Added

- Initial Version. Merging many Zenhub workspaces to a single github org project
